Class: Aws::IoTFleetHub::Types::DescribeApplicationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotfleethub/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_arn ⇒ String

The ARN of the web application.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/aws-sdk-iotfleethub/types.rb', line 210

class DescribeApplicationResponse < Struct.new(
  :application_id,
  :application_arn,
  :application_name,
  :application_description,
  :application_url,
  :application_state,
  :application_creation_date,
  :application_last_update_date,
  :role_arn,
  :sso_client_id,
  :error_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#application_creation_date ⇒ Integer

The date (in Unix epoch time) when the application was created.

Returns:

  • (Integer)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/aws-sdk-iotfleethub/types.rb', line 210

class DescribeApplicationResponse < Struct.new(
  :application_id,
  :application_arn,
  :application_name,
  :application_description,
  :application_url,
  :application_state,
  :application_creation_date,
  :application_last_update_date,
  :role_arn,
  :sso_client_id,
  :error_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#application_description ⇒ String

An optional description of the web application.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/aws-sdk-iotfleethub/types.rb', line 210

class DescribeApplicationResponse < Struct.new(
  :application_id,
  :application_arn,
  :application_name,
  :application_description,
  :application_url,
  :application_state,
  :application_creation_date,
  :application_last_update_date,
  :role_arn,
  :sso_client_id,
  :error_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#application_id ⇒ String

The unique Id of the web application.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/aws-sdk-iotfleethub/types.rb', line 210

class DescribeApplicationResponse < Struct.new(
  :application_id,
  :application_arn,
  :application_name,
  :application_description,
  :application_url,
  :application_state,
  :application_creation_date,
  :application_last_update_date,
  :role_arn,
  :sso_client_id,
  :error_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#application_last_update_date ⇒ Integer

The date (in Unix epoch time) when the application was last updated.

Returns:

  • (Integer)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/aws-sdk-iotfleethub/types.rb', line 210

class DescribeApplicationResponse < Struct.new(
  :application_id,
  :application_arn,
  :application_name,
  :application_description,
  :application_url,
  :application_state,
  :application_creation_date,
  :application_last_update_date,
  :role_arn,
  :sso_client_id,
  :error_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#application_name ⇒ String

The name of the web application.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/aws-sdk-iotfleethub/types.rb', line 210

class DescribeApplicationResponse < Struct.new(
  :application_id,
  :application_arn,
  :application_name,
  :application_description,
  :application_url,
  :application_state,
  :application_creation_date,
  :application_last_update_date,
  :role_arn,
  :sso_client_id,
  :error_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#application_state ⇒ String

The current state of the web application.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/aws-sdk-iotfleethub/types.rb', line 210

class DescribeApplicationResponse < Struct.new(
  :application_id,
  :application_arn,
  :application_name,
  :application_description,
  :application_url,
  :application_state,
  :application_creation_date,
  :application_last_update_date,
  :role_arn,
  :sso_client_id,
  :error_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#application_url ⇒ String

The URL of the web application.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/aws-sdk-iotfleethub/types.rb', line 210

class DescribeApplicationResponse < Struct.new(
  :application_id,
  :application_arn,
  :application_name,
  :application_description,
  :application_url,
  :application_state,
  :application_creation_date,
  :application_last_update_date,
  :role_arn,
  :sso_client_id,
  :error_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#error_message ⇒ String

A message that explains any failures included in the applicationState response field. This message explains failures in the CreateApplication and DeleteApplication actions.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/aws-sdk-iotfleethub/types.rb', line 210

class DescribeApplicationResponse < Struct.new(
  :application_id,
  :application_arn,
  :application_name,
  :application_description,
  :application_url,
  :application_state,
  :application_creation_date,
  :application_last_update_date,
  :role_arn,
  :sso_client_id,
  :error_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The ARN of the role that the web application assumes when it interacts with Amazon Web Services IoT Core.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/aws-sdk-iotfleethub/types.rb', line 210

class DescribeApplicationResponse < Struct.new(
  :application_id,
  :application_arn,
  :application_name,
  :application_description,
  :application_url,
  :application_state,
  :application_creation_date,
  :application_last_update_date,
  :role_arn,
  :sso_client_id,
  :error_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#sso_client_id ⇒ String

The Id of the single sign-on client that you use to authenticate and authorize users on the web application.

Returns:

  • (String)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/aws-sdk-iotfleethub/types.rb', line 210

class DescribeApplicationResponse < Struct.new(
  :application_id,
  :application_arn,
  :application_name,
  :application_description,
  :application_url,
  :application_state,
  :application_creation_date,
  :application_last_update_date,
  :role_arn,
  :sso_client_id,
  :error_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

A set of key/value pairs that you can use to manage the web application resource.

Returns:

  • (Hash<String,String>)


210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/aws-sdk-iotfleethub/types.rb', line 210

class DescribeApplicationResponse < Struct.new(
  :application_id,
  :application_arn,
  :application_name,
  :application_description,
  :application_url,
  :application_state,
  :application_creation_date,
  :application_last_update_date,
  :role_arn,
  :sso_client_id,
  :error_message,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end